@@ -94,6 +94,23 @@ private Q_SLOTS:
         QCOMPARE(waitTransaction(m_appBackend->removeApplication(ourResource)), Transaction::DoneStatus);
         QCOMPARE(ourResource->state(), AbstractResource::None);
     }
+
+    void testFlatpakref()
+    {
+        AbstractResourcesBackend::Filters f;
+        f.resourceUrl = QUrl(QStringLiteral("https://dl.flathub.org/repo/appstream/com.dosbox.DOSBox.flatpakref"));
+        const auto res = getResources(m_appBackend->search(f));
+        QCOMPARE(res.count(), 1);
+
+        f.resourceUrl = QUrl(QStringLiteral("appstream://dosbox.desktop"));
+        const auto res2 = getResources(m_appBackend->search(f));
+        QCOMPARE(res2, res);
+
+        f.resourceUrl = QUrl(QStringLiteral("appstream://com.dosbox.DOSBox.desktop"));
+        const auto res3 = getResources(m_appBackend->search(f));
+        QCOMPARE(res3, res);
+    }
+
     /*
         void testCancelInstallation()
         {
@@ -148,7 +165,7 @@ private:
         connect(stream, &ResultsStream::resourcesFound, this, [&resources](const QVector<AbstractResource *> &res) {
             resources += res;
         });
-        Q_ASSERT(spyResources.wait(10000));
+        Q_ASSERT(spyResources.wait(100000));
         Q_ASSERT(!resources.isEmpty() || canBeEmpty);
         return resources;
     }
